==> phpAdsNew_1.4.9.tar.gz: phpAdsNew_1.4.9/german.inc.php <==
<?

$date_format = "%d.%m.%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "MySQl-Fehler:";
$strAdminstration = "Adminstration";
$strAddClient = "Neuen Kunden hinzufgen";
$strModifyClient = "Kunde ndern";
$strDeleteClient = "Kunde lschen";
$strViewClientStats = "Kundenstatistik ansehen";
$strClientName = "Kunde";
$strContact = "Kontakt";
$strEMail = "EMail";
$strViews = "AdViews";
$strClicks = "AdClicks";
$strTotalViews = "Summe AdViews";
$strTotalClicks = "Summe AdClicks";
$strViewsPurchased = "Gekaufte AdViews";
$strClicksPurchased = "Gekaufte AdClicks";
$strHTML = "HTML";
$strAddSep = "Fill in EITHER the fields above OR the field below!"; //unused? mm, 22.11.1999
$strTextBelow = "Bildunterschrift";
$strSubmit = "Fertigstellen";
$strBannerAdmin = "Banner Adminstration fr";
$strNoBanners = "Keine Banner gefunden";
$strBanner = "Banner";
$strCurrentBanner = "Aktuelles Banner";
$strDelete = "Lschen";
$strAddBanner  = "Neues Banner hinzufgen";
$strModifyBanner  = "Banner bearbeiten";
$strURL = "Klick-URL (inkl. http://)";
$strKeyword = "Schlsselwort"; //Babelfish translation. - <weston@infinityteldata.net>
$strAlt = "Alt-Text";
$strUsername = "Username";
$strPassword = "Passwort";
$strAccessDenied = "Zugriff verweigert";
$strNotAdmin = "Sie haben keine Administrationsrechte";
$strClientAdded = "Der Benutzer wurde hinzugefgt.";
$strClientModified = "Der Benutzer wurde gendert.";
$strClientDeleted = "Der Benutzer wurde gelscht.";
$strBannerAdmin = "Banner Adminstration";
$strBannerAdded = "Das Banner wurde hinzugefgt.";
$strBannerModified = "Das Banner wurde gendert";
$strBannerDeleted = "Das Banner wurde gelscht";
$strBannerChanged = "Das Banner wurde gendert";
$strStats = "Statistiken";
$strDailyStats = "Tgliche Statistik";
$strDetailStats = "Detaillierte Statistik";
$strActive = "aktiv";
$strActivate = "Aktivieren";
$strDeActivate = "Deaktivieren";
$strAuthentification = "Authentifizierung";
$strGo = "Ok";
$strLinkedTo = "Klick URL";
$strBannerID = "Banner-ID";
$strClientID = "Kunden-ID";
$strMailSubject = "Banner-Report";
$strMailHeader = 'Guten Tag, ".$clients[$i][contact].",\n\n';
$strMailBannerStats = 'hiermit bersenden wir Ihnen die Bannerstatistik fr ".$clients[$i][clientname].":';
$strMailFooter = 'Mit freundlichen Gren,\n   $phpAds_admin_fullname';
$strMailNothingLeft = 'die AdViews Ihrer Banner haben das vorgegebene Ziel erreicht. Deshalb wurden Ihre Banner deaktiviert.\n\nWenn Sie die Kampagne weiterhin fortsetzen mchten, setzen Sie sich bitte mit uns in Verbindung.\nWir freuen und auf Ihre Antwort.';
$strLogMailSent = "[phpAds] Statistik erfolgreich verschickt.";
$strLogErrorClients = "[phpAds] Ein Fehler ist aufgetreten beim Versuch, den Benutzer in der Datenbank zu finden.";
$strLogErrorBanners = "[phpAds] Ein Fehler ist aufgetreten beim Versuch, die Banner in der Datenbank zu finden.";
$strLogErrorViews = "[phpAds] Ein Fehler ist aufgetreten beim Versuch, die Adviews in der Datenbank zu finden.";
$strLogErrorClicks = "[phpAds] Ein Fehler ist aufgetreten beim Versuch, die Adclicks in der Datenbank zu finden.";
$strLogErrorDisactivate = "[phpAds] Ein Fehler ist aufgetreten beim Versuch ein Banner zu deaktivieren.";
$strRatio = "Klickrate";
$strChooseBanner = "Bitte einen Bannertyp auswhlen.";
$strMySQLBanner = "Bild lokal verwalten";
$strURLBanner = "Bild ber URL verwalten";
$strHTMLBanner = "HTML Banner";
$strNewBannerFile = "Bilddateiname";
$strNewBannerURL = "Bild-URL (inkl. http://)";
$strWidth = "Breite";
$strHeight = "Hhe";
$strTotalViews7Days = "Summe AdViews der letzten 7 Tage";
$strTotalClicks7Days = "Summe AdClicks der letzten 7 Tage";
$strAvgViews7Days = "AdViews pro Tag (Durchschnitt der letzten 7 Tage)";
$strAvgClicks7Days = "AdClicks pro Tag (Durchschnitt der letzten 7 Tage)";

?>

==> phpAdsNew_1.6.0.tar.gz: phpAdsNew_1.6.0/german.inc.php <==
<?

$date_format = "%d.%m.%Y";
$time_format = "%H:%i:%S";
$strMySQLError = "MySQL-Fehler:";
$strAdminstration = "Adminstration";
$strAddClient = "Neuen Kunden hinzufgen";
$strModifyClient = "Kunde ndern";
$strDeleteClient = "Kunde lschen";
$strViewClientStats = "Kundenstatistik ansehen";
$strClientName = "Kunde";
$strContact = "Kontakt";
$strEMail = "EMail";
$strViews = "AdViews";
$strClicks = "AdClicks";
$strTotalViews = "Summe AdViews";
$strTotalClicks = "Summe AdClicks";
$strViewsPurchased = "Gekaufte AdViews";
$strClicksPurchased = "Gekaufte AdClicks";
$strDaysPurchased = "Gekaufte AdDays";
$strHTML = "HTML";
$strAddSep = "Bitte entweder die Felder oben oder das Feld unten ausfllen!"; //unused? mm, 22.11.1999
$strTextBelow = "Bildunterschrift";
$strSubmit = "Fertigstellen";
$strUsername = "Username";
$strPassword = "Passwort";
$strBannerAdmin = "Banner Adminstration fr";
$strBannerAdminAcl = "Banner ACL adminstration fr";
$strNoBanners = "Keine Banner gefunden";
$strBanner = "Banner";
$strCurrentBanner = "Aktuelles Banner";
$strDelete = "Lschen";
$strAddBanner  = "Neues Banner hinzufgen";
$strModifyBanner  = "Banner bearbeiten";
$strModifyBannerAcl  = "Banner ACL bearbeiten";
$strURL = "Klick-URL (inkl. http://)";
$strKeyword = "Schlsselwort"; //Babelfish translation. - <weston@infinityteldata.net>
$strWeight = "Gewicht";
$strAlt = "Alt-Text";
$strAccessDenied = "Zugriff verweigert";
$strNotAdmin = "Sie haben keine Administrationsrechte";
$strClientAdded = "Der Benutzer wurde hinzugefgt.";
$strClientModified = "Der Benutzer wurde gendert.";
$strClientDeleted = "Der Benutzer wurde gelscht.";
$strBannerAdmin = "Banner Adminstration";
$strBannerAdded = "Das Banner wurde hinzugefgt.";
$strBannerModified = "Das Banner wurde gendert";
$strBannerDeleted = "Das Banner wurde gelscht";
$strBannerChanged = "Das Banner wurde gendert";
$strStats = "Statistiken";
$strDailyStats = "Tgliche Statistik";
$strDetailStats = "Detaillierte Statistik";
$strActive = "aktiv";
$strActivate = "Aktivieren";
$strDeActivate = "Deaktivieren";
$strAuthentification = "Authentifizierung";
$strGo = "Ok";
$strLinkedTo = "Klick URL";
$strBannerID = "Banner-ID";
$strClientID = "Kunden-ID";
$strMailSubject = "Banner-Report";
$strMailSubjectDeleted = "Deaktiviertes Banner";
$strMailHeader = 'Guten Tag, ".$clients[$i][contact].",\n\n';
$strMailBannerStats = 'hiermit bersenden wir Ihnen die Bannerstatistik fr ".$clients[$i][clientname].":';
$strMailFooter = 'Mit freundlichen Gren,\n   $phpAds_admin_fullname';
$strMailNothingLeft = 'die AdViews Ihrer Banner haben das vorgegebene Ziel erreicht. Deshalb wurden Ihre Banner deaktiviert.\n\nWenn Sie die Kampagne weiterhin fortsetzen mchten, setzen Sie sich bitte mit uns in Verbindung.\nWir freuen und auf Ihre Antwort.';
$strLogMailSent = "[phpAds] Statistik erfolgreich verschickt.";
$strLogErrorClients = "[phpAds] Ein Fehler ist aufgetreten beim Versuch, den Benutzer in der Datenbank zu finden.";
$strLogErrorBanners = "[phpAds] Ein Fehler ist aufgetreten beim Versuch, die Banner in der Datenbank zu finden.";
$strLogErrorViews = "[phpAds] Ein Fehler ist aufgetreten beim Versuch, die Adviews in der Datenbank zu finden.";
$strLogErrorClicks = "[phpAds] Ein Fehler ist aufgetreten beim Versuch, die Adclicks in der Datenbank zu finden.";
$strLogErrorDisactivate = "[phpAds] Ein Fehler ist aufgetreten beim Versuch ein Banner zu deaktivieren.";
$strRatio = "Klickrate";
$strChooseBanner = "Bitte einen Bannertyp auswhlen.";
$strMySQLBanner = "Bild lokal verwalten";
$strURLBanner = "Bild ber URL verwalten";
$strHTMLBanner = "HTML Banner";
$strNewBannerFile = "Bilddateiname";
$strNewBannerURL = "Bild-URL (inkl. http://)";
$strWidth = "Breite";
$strHeight = "Hhe";
$strTotalViews7Days = "Summe AdViews der letzten 7 Tage";
$strTotalClicks7Days = "Summe AdClicks der letzten 7 Tage";
$strAvgViews7Days = "AdViews pro Tag (Durchschnitt der letzten 7 Tage)";
$strAvgClicks7Days = "AdClicks pro Tag (Durchschnitt der letzten 7 Tage)";
$strTopTenHosts = "Top ten anfordernde Hosts/Rechner";
$strConfirmDeleteClient = "Mchten Sie diesen Kunden wirklich lschen?";
$strClientIP = "Client IP";
$strUserAgent = "RegExp fr Browser";
$strWeekDay = "Wochentag (0 - 6)";
$strDomain = "Domain (ohne Punkt)";
$strSource = "Quelle";
$strAllow = "Erlauben";
$strDeny = "Verweigern";
?>
